django-comments-xtd — django-comments-xtd 2.0.10 documentation

# django-comments-xtd

A Django pluggable application that adds comments to your project. It extends the once official Django Comments Framework with the following features:

1. Thread support, so comments can be nested.
2. Customizable maximum thread level, either for all models or on a per app.model basis.
3. Optional notifications on follow-up comments via email.
4. Mute links to allow cancellation of follow-up notifications.
5. Comment confirmation via email when users are not authenticated.
6. Comments hit the database only after they have been confirmed.
7. Registered users can like/dislike comments and can suggest comments removal.
8. Template tags to list/render the last N comments posted to any given list of app.model pairs.
9. Emails sent through threads (can be disable to allow other solutions, like a Celery app).
10. Fully functional JavaScript plugin using ReactJS, jQuery, Bootstrap, Remarkable and MD5.

## Contents

- Quick start guide
- Tutorial
- Demo projects
- Control logic
- Web API
- JavaScript plugin
- Filters and template tags
- Migrating to django-comments-xtd
- Customizing django-comments-xtd
- Internationalization
- Settings
- Templates